@@ -195,8 +195,12 @@ class httptools():
         tp.wait()
         
         # 根据成功下载文件的数量判断是否下载完整，定义一个失败率
-        if len(os.listdir(m3u8TmpFileDir)) / len(tsFilePaths) < 1 - maxFailRate:
-            return 0
+        if len(tsFilePaths) == 0:
+            raise Exception("需要下载的ts文件数量为" + str(len(tsFilePaths)) + "，而下载成功的ts文件数量为" + str(len(m3u8TmpFileDir)))
+        elif len(os.listdir(m3u8TmpFileDir)) == 0:
+            raise Exception("需要下载的ts文件数量为" + str(len(tsFilePaths)) + "，而下载成功的ts文件数量为" + str(len(m3u8TmpFileDir)))
+        elif len(os.listdir(m3u8TmpFileDir)) / len(tsFilePaths) < 1 - maxFailRate:
+            raise Exception("需要下载的ts文件数量为" + str(len(tsFilePaths)) + "，而下载成功的ts文件数量为" + str(len(m3u8TmpFileDir)))
         
         # 解密并合并文件
         size = 0
